@@ -1,29 +1,36 @@
 
-# test plot.hagis.gene.summary ----------------------------------------------
-test_that("auto.plot.hagis.complexities() returns a ggplot2 object", {
-  data(P_sojae_survey)
-  complexities <- calculate_complexities(
-    x = P_sojae_survey,
-    cutoff = 60,
-    control = "susceptible",
-    sample = "Isolate",
-    gene = "Rps",
-    perc_susc = "perc.susc"
-  )
+# test plot.hagis.complexities.summary -----------------------------------------
+data(P_sojae_survey)
+complexities <- calculate_complexities(
+  x = P_sojae_survey,
+  cutoff = 60,
+  control = "susceptible",
+  sample = "Isolate",
+  gene = "Rps",
+  perc_susc = "perc.susc"
+)
+
+test_that("auto.plot.hagis.complexities() returns a ggplot2 object 4 cnt", {
   complexities_count <- autoplot(complexities, type = "count")
   vdiffr::expect_doppelganger("count_complexities",
                       complexities_count)
+})
 
+test_that("auto.plot.hagis.complexities() returns a ggplot2 object 4 %", {
   complexities_perc <- autoplot(complexities, type = "percentage")
   vdiffr::expect_doppelganger("perc_complexities",
                       complexities_perc)
+})
 
+test_that("auto.plot.hagis.complexities() rtns a blue ggplot2 object 4 %", {
   complexities_perc_blue <-
     autoplot(complexities, type = "percentage",
              color = "blue")
   vdiffr::expect_doppelganger("perc_complexities_blue",
                       complexities_perc_blue)
+})
 
+test_that("auto.plot.hagis.complexities() rtns descending ggplot2 object 4 %", {
   complexities_perc_desc_blue <-
     autoplot(complexities,
              type = "percentage",
@@ -31,7 +38,9 @@ test_that("auto.plot.hagis.complexities() returns a ggplot2 object", {
              order = "descending")
   vdiffr::expect_doppelganger("perc_complexities_desc_blue",
                       complexities_perc_desc_blue)
+})
 
+test_that("auto.plot.hagis.complexities() rtns ascending ggplot2 object 4 %", {
   complexities_perc_asc_blue <-
     autoplot(complexities,
              type = "percentage",
@@ -39,7 +48,9 @@ test_that("auto.plot.hagis.complexities() returns a ggplot2 object", {
              order = "ascending")
   vdiffr::expect_doppelganger("perc_complexities_asc_blue",
                       complexities_perc_asc_blue)
+})
 
+test_that("auto.plot.hagis.complexities() rtns ascend ggplot2 object 4 cnt", {
   complexities_count_asc_blue <-
     autoplot(complexities,
              type = "count",
@@ -47,7 +58,9 @@ test_that("auto.plot.hagis.complexities() returns a ggplot2 object", {
              order = "ascending")
   vdiffr::expect_doppelganger("count_complexities_asc_blue",
                       complexities_count_asc_blue)
+})
 
+test_that("auto.plot.hagis.complexities() errors on invalid type", {
   expect_error(autoplot(complexities, type = "orange"),
                regexp = "You have entered an invalid `type`.")
 })
